@@ -75,7 +75,7 @@ class NotificationFetcher(dbus.service.Object):
 
     @dbus.service.method(DBUS_PATH, in_signature="", out_signature="ssss")
     def GetServerInformation(self):
-        return "notification_fetcher", "github.com/sencer", "0.0.0", "1"
+        return "i3notifier", "github.com/sencer/i3-notifier", "0.11", "1"
 
     @dbus.service.method(DBUS_PATH, in_signature="susssasa{ss}i", out_signature="u")
     def Notify(
